;;   SS.LSP   Version 4.3
;;
;;   (C) Copyright 1999 by Design Point
;;   All rights reserved
;;
;;   This program is copyrighted by Design Point and is licensed
;;   to you under the following conditions.  You may not distribute
;;   or publish the source code, or any data files of this program
;;   in any form.
;;
;;   DESIGN POINT PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
;;   DESIGN POINT SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF MER-
;;   CHANTABILITY OR FITNESS FOR A PARTICULAR USE.  DESIGN POINT
;;   DOES NOT WARRANT THAT THE OPERATION OF THIS OR PARTS OF THIS
;;   PROGRAM WILL BE UNINTERRUPTED OR ERROR FREE.
;;

;; This file to be used in conjuction with SS.DCL

;; Supporting LSP Files:
;;    STL_DE0 - W  Shapes Cross Section
;;    STL_DE1 - S  Shapes Cross Section
;;    STL_DE2 - C  Shapes Cross Section
;;    STL_DE3 - WT Shapes Cross Section
;;    STL_DE4 - ST Shapes Cross Section
;;    STL_DE5 - Angle Shapes Cross Section
;;    STL_DE6 - TS Shapes Cross Section
;;    STL_DE7 - P  Shapes Cross Section
;;    STL_DF0 - W  Shapes Elevation
;;    STL_DF1 - C  Shapes Elevation
;;    STL_DF2 - WT/ST Shapes Elevation
;;    STL_DF3 - Angle Shapes Elevations
;;    STL_DF4 - TS/P Shapes Elevations
;;    STL_DT0 - W/WT Shapes Top/Bottom View
;;    STL_DT1 - C Shapes Top/Bottom View
;;    STL_3D0 - W  3D Shape
;;    STL_3D1 - S  3D Shape
;;    STL_3D2 - C  3D Shape
;;    STL_3D3 - WT 3D Shape
;;    STL_3D4 - ST 3D Shape
;;    STL_3D5 - Angle 3D Shape
;;    STL_3D6 - TS 3D Shape
;;    STL_3D7 - P  3D Shape

(defun stl_about ()
   (new_dialog "stl_about" STL_DCL_FILE)
   (start_dialog)
)
(defun stl_init ( a )
   (setq STL_DCL_FILE (load_dialog a))
   (command ".layer" "m" "STL-HIDN" "lt" "hidden" ""
                     "m" "STL-CNTR" "lt" "center" ""
                     "m" "STL-HTCH" "lt" "continuous" ""
                     "m" "STL-OBJT" "lt" "continuous" "" "")
)
(defun stl_set_lyr (x)
   (if (not (tblsearch "layer" x))
      (command ".layer" "m" x "" "")
      (setvar "clayer" x)
   )
)
(defun stl_draw_line (x y / a b)
   (setq b (getvar "blipmode"))
   (setvar "blipmode" 0)
   (command ".line")
   (foreach a x
      (command a)
   )
   (cond
      ((and y) (command "c"))
      (t (command))
   )
   (setvar "blipmode" b)
)
(defun stl_90  (x) (+ x (* pi 0.5)))
(defun stl_180 (x) (+ x pi))
(defun stl_270 (x) (+ x (* pi 1.5)))
(defun stl_clr_data ()
   (mapcar 'set_tile
      '("stl_current_shape"
        "shp_size"
        "shp_flange"
        "shp_web"
        "shp_halfweb"
        "shp_stiff"
        "shp_gage"
        "shp_cope")
      '("" "" "" "" "" "" "" "")
   )
)
(defun stl_a (/ a b)
   (setq SHP_DATA nil
         SHP_LIST_A nil
         SHP_LABEL_A nil
         STL_SHP_A nil
         SHP_LIST_B nil
         SHP_LABEL_B nil
         STL_SHP_B nil)
   (stl_clr_data)
   (setq a (get_tile "stl_shapes"))
   (if (/= a STL_SHP)
      (progn
         (start_list "stl_size_b")
         (add_list "")
         (end_list)
         (set_tile "size_b_label" "")
      )
   )
   (setq STL_SHP a)
   (stl_d t)
   (if (findfile (setq a (strcat "stl_shp" STL_SHP ".stl")))
      (progn
         (setq FUNCTION_LIST (car (load a)))
         (set_tile "size_a_label" (setq SHP_LABEL_A (nth (atoi STL_SHP) SHP_LIST)))
         (start_list "stl_size_a")
         (foreach b (cdr SHP_LIST_A)
            (add_list (car b))
         )
         (end_list)
      )
      (alert (strcat "Can not find shape data file [" (strcase a) "]\n\nMake sure this file is in your ACAD search path."))
   )
)
(defun stl_b (/ a b)
   (setq a (setq STL_SHP_A (get_tile "stl_size_a")))
   (setq SHP_LIST_B (cdr (nth (atoi a) (cdr SHP_LIST_A))))
   (set_tile "size_b_label" (setq SHP_LABEL_B (car (nth (atoi a) (cdr SHP_LIST_A)))))
   (start_list "stl_size_b")
   (foreach b SHP_LIST_B
      (add_list (car b))
   )
   (end_list)
   ;(setq SHP_DATA nil) will nil out everything before going forward
   ;this developer enjoys, at this, time the default shape capability.
)
(defun stl_c (/ a b)
   (setq a (setq STL_SHP_B (get_tile "stl_size_b")))
   (setq SHP_DATA (nth (atoi a) SHP_LIST_B))
   (if (and SHP_DATA)
      (progn
         (set_tile "stl_current_shape" (strcat "Current Shape:  " (car SHP_DATA)))
         (stl_h)
         (set_tile "stl_err_msg" "")
      )
   )
)
(defun stl_d (x / a b c)
   (if (= (strcase STL_VIS_MODE) "STL_VMA")
      (progn
         (setq a (list (nth (atoi STL_SHP) SHP_LIST) STL_VIEW_MODE))
         (setq c STL_INPUT_MODE)
         (setq b
            (cond
               ((member (car  a) '("Angles" "Tubing" "Pipe")) '(0 0 0 0))
               ((member (cadr a) '("stl_va" "stl_vb")) '(0 0 0 1))
               ((member (cadr a) '("stl_vc" "stl_vd")) '(0 0 1 0))
               (t '(0 0 0 0))
            )
         )
         ; Set default input buttons
         (if (and x)
            (progn
               (cond
                  ((and
                     (member (car a) '("W Shapes" "M Shapes" "S Shapes" "HP Shapes"
                                       "WT Shapes" "MT Shapes" "ST Shapes" "Tubing"))
                     (member (cadr a) '("stl_vc" "stl_vd")))
                     (set_tile "stl_id" "1")
                  )
                  ((and
                     (member (car a) '("C Shapes" "MC Shapes"))
                     (member (cadr a) '("stl_vc")))
                     (set_tile "stl_ib" "1")
                  )
                  (t
                     (set_tile
                        (nth (atoi STL_SHP) '("stl_ia"          ;W Shapes
                                              "stl_ia"          ;M Shapes
                                              "stl_ia"          ;S Shapes
                                              "stl_ia"          ;HP Shapes
                                              "stl_ia"          ;C Shapes
                                              "stl_ia"          ;MC Shapes
                                              "stl_ia"          ;WT Shapes
                                              "stl_ia"          ;MT Shapes
                                              "stl_ia"          ;ST Shapes
                                              "stl_ia"          ;Angles
                                              "stl_ic"          ;Tubing
                                              "stl_ic")) "1")   ;Pipe
                  )
               )
               (setq STL_INPUT_MODE (get_tile "stl_input_mode"))
            )
         )
         (if (/= STL_INPUT_MODE c)
            (set_tile "stl_err_msg" "Switching input mode to default setting")
            (set_tile "stl_err_msg" "")
         )
         (mapcar 'mode_tile '("stl_ia" "stl_ib" "stl_ic" "stl_id") b)
      )
   )
)
(defun stl_e ()
   (if (not SHP_DATA)
      (set_tile "stl_err_msg" "You must first select a shape")
      (progn
         (done_dialog)
         (setq b t)
      )
   )
)
(defun stl_f ( x / a )
   (setq STL_SVLIST
      (list
         (list "blipmode"  (getvar "blipmode" ))
         (list "highlight" (getvar "highlight"))
         (list "osmode"    (getvar "osmode"   ))
         (list "clayer"    (getvar "clayer"   ))
      )
   )
   (cond
      ((null x) nil)
      (t (foreach a x (setq STL_SVLIST (append STL_SVLIST (list (list a (getvar a)))))))
   )
)
(defun stl_g ( / a )
   (foreach a SD_SVLIST (setvar (car a) (cadr a)))
   (setq SD_SVLIST nil)
)
(defun stl_vis (x)
   (setq a
      (list
         "stl_va" "stl_vb" "stl_vc" "stl_vd" "stl_ve"
         "stl_ia" "stl_ib" "stl_ic" "stl_id"
         "stl_ha" "stl_hb"
      )
   )
   (setq STL_VIS_MODE x)
   (cond
      ((= (strcase x) "STL_VMA")
         (mapcar 'mode_tile a
           '(0 0 0 0 0
             0 0 0 0
             0 0
            )
         )
      )
      ((= (strcase x) "STL_VMB")
         (mapcar 'mode_tile a
           '(1 1 1 1 1
             0 0 0 1
             1 1
            )
         )
         (if (= (get_tile "stl_input_mode") "stl_id") (set_tile "stl_ia" "1"))
      )
   )
)
(defun stl_h (/ a b c d e f g)
   (cond
      ((= (car SHP_DATA) " ") (setq SHP_DATA nil) (stl_clr_data))
      ((not (setq g (nth (atoi STL_SHP) SHP_LIST))))
      ((member g
           '("W Shapes"  "M Shapes"  "HP Shapes"
             "WT Shapes" "MT Shapes" "S Shapes")
       )
         (set_tile "shp_size"    (strcat "Nominal size:\t" (setq b (rtos (nth 1 SHP_DATA) 5 3)) " x " (setq d (rtos (nth 3 SHP_DATA) 5 3))))
         (set_tile "shp_flange"  (strcat "Flange:      \t" (setq c (rtos (nth 4 SHP_DATA) 5 4))))
         (set_tile "shp_web"     (strcat "Web:         \t" (rtos (nth 2 SHP_DATA) 5 4)))
         (set_tile "shp_halfweb" (strcat "1/2 web:     \t" (setq e (rtos (+ 0.015625 (/ (nth 2 SHP_DATA) 2.0)) 5 4))))
         (setq a (- (/ (distof d 2) 2.0) (distof e 2) 0.125))
         (set_tile "shp_stiff"
            (strcat "Stiffener size:\t"
               (if (>= a 3)
                  (rtos a 5 1)
                  (rtos a 5 2)
               )
               " x "
               (rtos (- (distof b 2) (* 2.0 (distof c 2)) 0.125) 5 3)
            )
         )
         (setq g (if (= g "S Shapes") 9 8))
         (if (not (nth g SHP_DATA))
            (set_tile "shp_gage"         "Gage:        \tNA")
            (set_tile "shp_gage" (strcat "Gage:        \t" (rtos (nth g SHP_DATA) 5 3)))
         )
         (set_tile "shp_cope"
            (strcat "Cope:        \t"
               (rtos (+ (/ (distof d 2) 2.0) 0.5) 5 2)
               " x "
               (rtos (+ (nth 5 SHP_DATA) 0.03125) 5 2)
            )
         )
      )
      ((member g '("C Shapes" "MC Shapes" "ST Shapes"))
         (set_tile "shp_size"    (strcat "Nominal size:\t" (setq b (rtos (nth 1 SHP_DATA) 5 3)) " x " (setq d (rtos (nth 3 SHP_DATA) 5 3))))
         (set_tile "shp_flange"  (strcat "Flange:      \t" (setq c (rtos (nth 4 SHP_DATA) 5 4))))
         (set_tile "shp_web"     (strcat "Web:         \t" (setq f (rtos (nth 2 SHP_DATA) 5 4))))
         (set_tile "shp_halfweb" (strcat "1/2 web:     \t" (setq e (rtos (+ 0.015625 (/ (nth 2 SHP_DATA) 2.0)) 5 4))))
         (setq a (- (distof d 2) (distof e 2) 0.125))
         (set_tile "shp_stiff"
            (strcat "Stiffener size:\t"
               (if (>= a 3)
                  (rtos a 5 1)
                  (rtos a 5 2)
               )
               " x "
               (rtos (- (distof b 2) (* 2.0 (distof c 2)) 0.125) 5 3)
            )
         )
         (if (not (nth 10 SHP_DATA))
            (set_tile "shp_gage"         "Gage:        \tNA")
            (set_tile "shp_gage" (strcat "Gage:        \t" (rtos (nth 10 SHP_DATA) 5 3)))
         )
         (set_tile "shp_cope"
            (strcat "Cope:        \t"
               (rtos (+ (- (distof d 2) (distof f 2)) 0.5) 5 2)
               " x "
               (rtos (+ (nth 5 SHP_DATA) 0.03125) 5 2)
            )
         )
      )
      ((= "Angles" g)
         (set_tile "shp_size"   (strcat "Nominal size: \t" (setq b (rtos (nth 1 SHP_DATA) 5 3)) " x " (setq d (rtos (nth 2 SHP_DATA) 5 3))))
         (set_tile "shp_flange" (strcat "Leg thickness:\t" (setq c (rtos (nth 3 SHP_DATA) 5 4))))
         (set_tile "shp_web"    (strcat "lbs\\linear ft:\t" (rtos (nth 4 SHP_DATA) 2 1)))
         (setq a (- (distof d 2) (distof c 2) (/ (distof c 2) 2.0)))
         (setq e (- (distof b 2) (distof c 2) (/ (distof c 2) 2.0)))
         (set_tile "shp_stiff"
            (strcat "Stiffener size:\t"
               (if (>= a 3)
                  (setq f (rtos a 5 1))
                  (setq f (rtos a 5 2))
               )
               " x "
               (if (= a e) f (rtos e 5 3))
            )
         )
         (if (= b d)
            (progn
               (set_tile "shp_gage"
                  (strcat "GOL:\t\t" (rtos (nth 8 SHP_DATA) 5 3)
                     (if (>= (distof b 2) 5)
                        (strcat "\tDbl:\t" (rtos (nth 10 SHP_DATA) 5 2) " , " (rtos (nth 11 SHP_DATA) 5 2))
                        ""
                     )
                  )
               )
               (set_tile "shp_cope" "")
            )
            (progn
               (set_tile "shp_gage"
                  (strcat b "\" GOL: \t" (rtos (nth 8 SHP_DATA) 5 3)
                     (if (>= (distof b 2) 5)
                        (strcat "\tDbl:\t" (rtos (nth 10 SHP_DATA) 5 2) " , " (rtos (nth 11 SHP_DATA) 5 2))
                        ""
                     )
                  )
               )
               (set_tile "shp_cope" (strcat d "\" GOL: \t" (rtos (nth 9 SHP_DATA) 5 3)))
            )
         )
      )
      ((= "Tubing" g)
         (set_tile "shp_size"   (strcat "Nominal size:  \t" (rtos (nth 1 SHP_DATA) 5 3) " x " (rtos (nth 2 SHP_DATA) 5 3)))
         (set_tile "shp_flange" (strcat "Wall thickness:\t" (rtos (nth 3 SHP_DATA) 5 4)))
         (set_tile "shp_web"    (strcat "lbs\\linear ft:\t" (rtos (nth 4 SHP_DATA) 2 1)))
      )
      ((= "Pipe" g)
         (set_tile "shp_size"    (strcat "ID:            \t" (rtos (nth 2 SHP_DATA) 5 4)))
         (set_tile "shp_flange"  (strcat "OD:            \t" (rtos (nth 1 SHP_DATA) 5 4)))
         (set_tile "shp_web"     (strcat "Wall thickness:\t" (rtos (nth 3 SHP_DATA) 5 4)))
         (set_tile "shp_halfweb" (strcat "lbs\\linear ft:\t" (rtos (nth 4 SHP_DATA) 2 1)))
      )
   )
)
(defun c:steel_shapes (/ a b c d e stl_err)
   (stl_f nil)
   (setvar "cmdecho" 0)
   (setq stl_err *error*
         *error* '((a)
            (cond
               ((= (setq a (strcase a)) "FUNCTION CANCELLED") (princ "\n*Function Cancelled by User*"))
               (t (princ (strcat "\n*AutoLisp Error* [" a "]")))
            )
            (setq *error* stl_err)
            (stl_g)
            (princ)
         )
   )
   (setq e (getvar "clayer"))
   (cond
      (STL_DCL_FILE)
      ((setq a (findfile "steel.dcl")) (stl_init a)); Assumed Startup -- Initialize globals
      (t (alert "Can not find file STEEL.DCL\n\nMake sure this file is in your ACAD search path."))
   )
   (cond
      (STL_DCL_FILE
         (if (not STL_VIEW_MODE)
            (setq STL_VIEW_MODE "stl_va")
         )
         (if (not STL_DRAW_MODE)
            (setq STL_DRAW_MODE "stl_da")
         )
         (if (not STL_HATCH_MODE)
            (setq STL_HATCH_MODE "stl_ha")
         )
         (if (not STL_INPUT_MODE)
            (setq STL_INPUT_MODE "stl_ia")
         )
         (if (not STL_VIS_MODE)
            (setq STL_VIS_MODE "stl_vma")
         )
         (new_dialog "steel_shapes" STL_DCL_FILE)
         (if (and SHP_DATA)
            (progn
               (set_tile "stl_current_shape" (strcat "Current Shape:  " (car SHP_DATA)))
               (stl_h)
            )
         )
         (if (and SHP_DATA) (stl_d nil))
         (set_tile STL_VIEW_MODE "1")
         (set_tile STL_DRAW_MODE "1")
         (set_tile STL_HATCH_MODE "1")
         (set_tile STL_INPUT_MODE "1")
         (set_tile STL_VIS_MODE "1")
         (stl_vis STL_VIS_MODE)
         (start_list "stl_shapes")
         (mapcar 'add_list (setq SHP_LIST (list "W Shapes" "M Shapes" "S Shapes" "HP Shapes" "C Shapes" "MC Shapes" "WT Shapes" "MT Shapes" "ST Shapes" "Angles" "Tubing" "Pipe")))
         (end_list)
         (if (and STL_SHP) (set_tile "stl_shapes" STL_SHP))
         (if (and SHP_LIST_A)
            (progn
               (start_list "stl_size_a")
               (foreach b (cdr SHP_LIST_A)
                  (add_list (car b))
               )
               (end_list)
               (if (and STL_SHP_A) (set_tile "stl_size_a" STL_SHP_A))
               (if (and SHP_LABEL_A) (set_tile "size_a_label" SHP_LABEL_A))
            )
         )
         (if (and SHP_LIST_B)
            (progn
               (start_list "stl_size_b")
               (foreach b SHP_LIST_B
                  (add_list (car b))
               )
               (end_list)
               (if (and STL_SHP_B) (set_tile "stl_size_b" STL_SHP_B))
               (if (and SHP_LABEL_B) (set_tile "size_b_label" SHP_LABEL_B))
            )
         )
         (action_tile "stl_shapes" "(stl_a)")
         (action_tile "stl_size_a" "(stl_b)")
         (action_tile "stl_size_b" "(stl_c)")
         (action_tile "stl_view_mode" "(progn (setq STL_VIEW_MODE (get_tile \"stl_view_mode\")) (stl_d t))")
         (action_tile "stl_draw_mode" "(setq STL_DRAW_MODE (get_tile \"stl_draw_mode\"))")
         (action_tile "stl_hatch_mode" "(setq STL_HATCH_MODE (get_tile \"stl_hatch_mode\"))")
         (action_tile "stl_input_mode" "(progn (set_tile \"stl_err_msg\" \"\") (setq STL_INPUT_MODE (get_tile \"stl_input_mode\")))")
         (action_tile "stl_accept" "(stl_e)")
         (action_tile "about_button" "(stl_about)")
         (action_tile "stl_cancel" "(progn (done_dialog) (setq b nil))")
         (start_dialog)
         (if (and b)
            (progn
               (if (= STL_VIS_MODE "stl_vma")
                  (cond
                     ((= STL_VIEW_MODE "stl_va") (load (nth 0 FUNCTION_LIST)))
                     ((= STL_VIEW_MODE "stl_vb") (load (nth 1 FUNCTION_LIST)))
                     ((= STL_VIEW_MODE "stl_vc") (load (nth 2 FUNCTION_LIST)))
                     ((= STL_VIEW_MODE "stl_vd") (load (nth 3 FUNCTION_LIST)))
                     ((= STL_VIEW_MODE "stl_ve") (load (nth 4 FUNCTION_LIST)))
                  )
                  (load (last FUNCTION_LIST))
               )
            )
         )
      )
   )
   (stl_set_lyr e)
   (setq *error* stl_err)
   (stl_g)
   (princ)
)
(defun c:ss () (c:steel_shapes))
(princ "\nSteel Shapes - Version 4.3 - by Design Point now loaded.")
(princ"\nType SS to start command.")
(princ)
